@@ -6,5 +6,6 @@ DEFAULT_SETTINGS = {'REWRITE' : True,
                     'CLIENT_ID' : True,
                     'HOSTS' : [],
                     'NO_COOKIE_PERSIST' : True,
-                    'URL_SPECIFIC' : False
+                    'URL_SPECIFIC' : False,
+                    'COOKIES_DELETE' : False
                     }
